@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION=q{3.2.08};
+our $VERSION=q{3.2.09};
 
 our @MANIFEST = (
 'clear.sh',
@@ -1988,15 +1988,29 @@ PROXY_START_SCRIPT
 #!_BINBASH_
 __LICENSE__
 
+cd $(dirname $0)
 __SBINSTR_SH__
 OLD_PORT=_SERVERPORT_
 
 if [ "$1" = "" ]
 then
-    echo "new port required"
+    echo "New port required as argument."
     exit
 else
-    NEW_PORT=$1
+    ONLY_DIGITS_REGEX="^[[:digit:]]+$"
+    if [[ $1 =~ ${ONLY_DIGITS_REGEX} ]]
+    then
+        if [[ $1 -ge 1 ]] && [[ $1 -le 65535 ]]
+        then
+            NEW_PORT=$1
+        else
+            echo "New port must be a valid port number in the 1-65535 range."
+            exit
+        fi
+    else
+        echo "New port must contain only digits (unsigned integer)."
+        exit
+    fi
 fi
 
 if [ $OLD_PORT = $NEW_PORT ]
